@@ -47,10 +47,11 @@ enum Command {
     /// List commodities
     #[structopt(alias = "currencies")]
     Commodities(CommonOpts),
-    /// List commodities
+    /// Show statistics about your ledger
     #[structopt(alias = "stats")]
     Statistics(CommonOpts),
 
+    /// Profitability calculations
     #[structopt(alias = "roi")]
     ReturnOnInvestment {
         #[structopt(flatten)]
@@ -138,7 +139,7 @@ pub struct CommonOpts {
     #[structopt(long = "--convert", short = "-C")]
     pub convert: Option<String>,
 
-    /// TODO Date format
+    /// Date format
     #[structopt(long = "--date-format", default_value = "%y-%b-%d")]
     pub date_format: String,
 
@@ -209,9 +210,11 @@ fn init_paths(args: Vec<String>) -> Result<Vec<String>, Box<dyn std::error::Erro
         } else if args[i] == INIT_FILE_FLAG {
             let file = Path::new(&args[i + 1]);
             if !file.exists() {
-                return Err(Box::new(MissingFileError::ConfigFileDoesNotExistError(
+                let failed = MissingFileError::ConfigFileDoesNotExistError(
                     file.to_path_buf(),
-                )));
+                );
+                eprintln!("{}", &failed);
+                return Err(Box::new(failed));
             }
             possible_paths.push(args[i + 1].clone());
             continue;
@@ -245,7 +248,7 @@ pub fn run_app(input_args: Vec<String>) -> Result<(), Box<dyn std::error::Error>
         input_args
     };
 
-    match Opt::from_iter_safe(args.iter()) {
+    let result = match Opt::from_iter_safe(args.iter()) {
         Err(error) => match Repl::from_iter_safe(args.iter()) {
             Ok(opt) => {
                 if !opt.options.query.is_empty() {
@@ -322,7 +325,15 @@ pub fn run_app(input_args: Vec<String>) -> Result<(), Box<dyn std::error::Error>
             Err(_) => error.exit(),
         },
         Ok(opt) => execute_command(opt, None),
+    };
+
+    if let Err(ref err) = result {
+        let message = format!("{}", err);
+        if !message.is_empty() {
+            eprintln!("{}", message);
+        }
     }
+    result
 }
 
 fn parse_config_file(file: &Path, input_args: &[String]) -> Vec<String> {
