@@ -6,6 +6,7 @@ use prettytable::Table;
 
 use crate::app::PeriodGroup;
 use crate::commands::balance::convert_balance;
+use crate::error::ReportError::CurrencyConversionError;
 use crate::models::{conversion, Balance, Ledger, Money};
 use crate::parser::value_expr::build_root_node_from_expression;
 use crate::{filter, CommonOpts};
@@ -13,7 +14,6 @@ use chrono::{Datelike, Duration, NaiveDate};
 use num::{BigInt, BigRational, Zero};
 use std::collections::HashMap;
 use std::convert::TryFrom;
-
 /// ROI (return on investment) report
 pub fn execute(
     options: &CommonOpts,
@@ -69,6 +69,7 @@ pub fn execute(
     let mut last_date = None;
 
     let mut periods: Vec<Period> = vec![];
+    let mut cash_flows: Vec<Cashflow> = vec![];
 
     for t in ledger.transactions.iter() {
         // cash_flows
@@ -84,27 +85,38 @@ pub fn execute(
             }
             last_date = Some(p.date);
 
-            match currency.as_ref() {
-                Some(_) => (),
-                None => {
-                    currency = Some(p.amount.as_ref().unwrap().get_commodity().unwrap().clone())
-                }
+            if currency.as_ref().is_none() {
+                currency = Some(p.amount.as_ref().unwrap().get_commodity().unwrap().clone())
             }
             if p.amount.as_ref().unwrap().get_commodity().unwrap()
                 == currency.as_ref().unwrap().clone()
             {
                 period.add_cash(p.amount.as_ref().unwrap().to_owned());
+                cash_flows.push(Cashflow {
+                    date: p.date,
+                    value: p.amount.as_ref().unwrap().get_amount().to_f64().unwrap(),
+                });
             } else {
                 let multipliers =
                     conversion(currency.as_ref().unwrap().clone(), p.date, &ledger.prices);
-                let mult = multipliers
-                    .get(p.amount.as_ref().unwrap().get_commodity().unwrap().as_ref())
-                    .unwrap();
-                let new_amount = Money::Money {
-                    amount: p.amount.as_ref().unwrap().get_amount() * mult.clone(),
-                    currency: currency.as_ref().unwrap().clone(),
-                };
-                period.add_cash(new_amount);
+                if let Some(mult) =
+                    multipliers.get(p.amount.as_ref().unwrap().get_commodity().unwrap().as_ref())
+                {
+                    let new_amount = Money::Money {
+                        amount: p.amount.as_ref().unwrap().get_amount() * mult.clone(),
+                        currency: currency.as_ref().unwrap().clone(),
+                    };
+                    period.add_cash(new_amount.clone());
+                    cash_flows.push(Cashflow {
+                        date: p.date,
+                        value: new_amount.get_amount().to_f64().unwrap(),
+                    });
+                } else {
+                    return Err(Box::new(CurrencyConversionError(
+                        p.amount.as_ref().unwrap().get_commodity().unwrap().as_ref().clone(),
+                        currency.as_ref().unwrap().as_ref().clone(),
+                    )));
+                }
             }
         } // cash flows
 
@@ -158,8 +170,7 @@ pub fn execute(
             let multipliers = conversion(currency.as_ref().unwrap().clone(), p.end, &ledger.prices);
             p.final_money = Some(
                 convert_balance(&p.final_balance, &multipliers, currency.as_ref().unwrap())
-                    .to_money()
-                    .unwrap(),
+                    .to_money()?,
             );
         }
         if p.initial_money.is_none() {
@@ -175,6 +186,21 @@ pub fn execute(
         prev_final_balance = p.final_balance.clone();
         prev_final_money = p.final_money.clone();
     }
+
+    cash_flows.push(Cashflow {
+        date: periods.iter().last().unwrap().end,
+        value: periods
+            .iter()
+            .last()
+            .unwrap()
+            .final_money
+            .as_ref()
+            .unwrap()
+            .get_amount()
+            .to_f64()
+            .unwrap(),
+    });
+
     match calendar {
         false => print_normal(&periods, options),
         true => print_calendar(&periods, &frequency),
@@ -186,6 +212,7 @@ pub fn execute(
         // Period: 5.41 years.
         // Annualized TWR: 10.12%
         let mut total_twr = 1.0;
+        let irr = irr(&cash_flows);
         for p in periods.iter() {
             total_twr *= 1.0 + p.twr().to_f64().unwrap();
             // dbg!(&total_twr);
@@ -198,10 +225,54 @@ pub fn execute(
         println!("Total TWR: {:.2}%", total_twr * 100.0);
         println!("Period: {:.2} years", num_days / 365.25);
         println!("Annualized TWR: {:.2}%", twr_annualized * 100.0);
+        println!("Annualized IRR: {:.2}%", irr * 100.0);
     }
     Ok(())
 }
 
+/// A cashflow, it does not need full precision and does not need a currency
+#[derive(Debug)]
+struct Cashflow {
+    date: NaiveDate,
+    value: f64,
+}
+
+fn irr(cash_flows: &[Cashflow]) -> f64 {
+    let tol = 1e-6;
+    let mut dif: f64 = &tol * 10.0;
+    let mut rate = 0.0;
+    let max_iters = 50;
+    let mut iters = 0;
+    while iters < max_iters && tol < dif.abs() {
+        iters += 1;
+        let f = npv(cash_flows, rate);
+        let df = npv_derivative(cash_flows, rate);
+        dif = f / df;
+        rate -= dif;
+    }
+    rate
+}
+fn npv(movements: &[Cashflow], rate: f64) -> f64 {
+    let mut npv = 0.0;
+    let first_date = movements[0].date;
+    for movement in movements.iter() {
+        let period = (movement.date - first_date).num_days().to_f64().unwrap() / 365.25;
+        npv += movement.value / (1.0 + rate).powf(period);
+    }
+    npv
+}
+
+fn npv_derivative(movements: &[Cashflow], rate: f64) -> f64 {
+    let mut npv = 0.0;
+    let first_date = movements[0].date;
+    for movement in movements.iter() {
+        let period = (movement.date - first_date).num_days().to_f64().unwrap() / 365.25;
+        let num = -movement.value * period * (1.0 + rate).powf(period - 1.0);
+        let den = (1.0 + rate).powf(period).powf(2.0);
+        npv += num / den;
+    }
+    npv
+}
 fn print_calendar(periods: &[Period], frequency: &Frequency) {
     let mut table = Table::new();
     table.set_format(*format::consts::FORMAT_NO_LINESEP_WITH_TITLE);
