@@ -482,6 +482,7 @@ fn related() {
 
     test_args(args);
 }
+
 #[test]
 fn empty_file() {
     let args = &[
@@ -492,7 +493,36 @@ fn empty_file() {
         "tests/example_files/empty_ledgerrc",
     ];
     let assert_1 = Command::cargo_bin("dinero").unwrap().args(args).assert();
-    let output = String::from_utf8(assert_1.get_output().to_owned().stdout).unwrap();
+    let output = String::from_utf8(assert_1.get_output().to_owned().stderr).unwrap();
+    for (i, line) in output.lines().enumerate() {
+        match i {
+            0 => assert_eq!(line, "The journal file does not have any information"),
+            1 => (),
+            _ => unreachable!("The output should have only two lines"),
+        }
+    }
+
+    test_err(args);
+}
+
+#[test]
+/// If this fails it means that it created an extra posting
+fn roi_conversion_fail() {
+    let args = &[
+        "roi",
+        "--init-file",
+        "tests/example_files/empty_ledgerrc",
+        "-f",
+        "tests/example_files/roi_fail_currencies.ledger",
+        "--cash-flows",
+        "cash",
+        "--assets-value",
+        "snake",
+        "-Q",
+    ];
+    let assert_1 = Command::cargo_bin("dinero").unwrap().args(args).assert();
+    let output_err = String::from_utf8(assert_1.get_output().to_owned().stderr).unwrap();
+    assert_eq!(output_err.lines().into_iter().count(), 1);
 
     test_err(args);
 }
